@@ -2,8 +2,7 @@
 package MooseX::AttributeHelpers::MethodProvider::String;
 use Moose::Role;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub append : method { 
@@ -68,33 +67,10 @@ sub inc : method {
 }
 
 sub clear : method {
-    my ($attr, $reader, $writer) = @_;
+    my ($attr, $reader, $writer ) = @_;
     return sub { $writer->( $_[0], '' ) }
 }
 
-sub substr : method {
-    my ($attr, $reader, $writer) = @_;
-    return sub {
-        my $self = shift;
-        my $v = $reader->($self);
-
-        my $offset      = defined $_[0] ? shift : 0;
-        my $length      = defined $_[0] ? shift : CORE::length($v);
-        my $replacement = defined $_[0] ? shift : undef;
-
-        my $ret;
-        if (defined $replacement) {
-            $ret = CORE::substr($v, $offset, $length, $replacement);
-            $writer->($self, $v);
-        }
-        else {
-            $ret = CORE::substr($v, $offset, $length);
-        }
-
-        return $ret;
-    };
-}
-
 1;
 
 __END__
@@ -138,8 +114,6 @@ L<MooseX::AttributeHelpers::String>.
 
 =item B<clear>
 
-=item B<substr>
-
 =back
 
 =head1 BUGS
@@ -154,7 +128,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
